@@ -60,6 +60,13 @@ typedef enum __attribute__((__packed__)) FFDisplayHdrStatus
     FF_DISPLAY_HDR_STATUS_ENABLED,
 } FFDisplayHdrStatus;
 
+typedef enum __attribute__((__packed__)) FFDisplayVrrStatus
+{
+    FF_DISPLAY_DRR_STATUS_UNKNOWN,
+    FF_DISPLAY_DRR_STATUS_DISABLED,
+    FF_DISPLAY_DRR_STATUS_ENABLED,
+} FFDisplayVrrStatus;
+
 typedef struct FFDisplayResult
 {
     uint32_t width; // in px
@@ -83,6 +90,7 @@ typedef struct FFDisplayResult
     uint16_t manufactureYear;
     uint16_t manufactureWeek;
     uint32_t serial;
+    FFDisplayVrrStatus drrStatus;
 } FFDisplayResult;
 
 typedef struct FFDisplayServerResult
