@@ -59,21 +59,18 @@ FF_MAYBE_UNUSED static bool detectArmbianVersion(FFOSResult* result)
     return true;
 }
 
-FF_MAYBE_UNUSED static void getUbuntuFlavour(FFOSResult* result)
+// Returns false if PrettyName should be updated by caller
+FF_MAYBE_UNUSED static bool getUbuntuFlavour(FFOSResult* result)
 {
-    const char* xdgConfigDirs = getenv("XDG_CONFIG_DIRS");
-    if(!ffStrSet(xdgConfigDirs))
-        return;
-
     if (detectArmbianVersion(result))
-        return;
+        return true;
     else if(ffStrbufStartsWithS(&result->prettyName, "Linux Lite "))
     {
         ffStrbufSetStatic(&result->name, "Linux Lite");
         ffStrbufSetStatic(&result->id, "linuxlite");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
         ffStrbufSetS(&result->versionID, result->prettyName.chars + strlen("Linux Lite "));
-        return;
+        return true;
     }
     else if(ffStrbufStartsWithS(&result->prettyName, "Rhino Linux "))
     {
@@ -81,103 +78,107 @@ FF_MAYBE_UNUSED static void getUbuntuFlavour(FFOSResult* result)
         ffStrbufSetStatic(&result->id, "rhinolinux");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
         ffStrbufSetS(&result->versionID, result->prettyName.chars + strlen("Rhino Linux "));
-        return;
+        return true;
     }
     else if(ffStrbufStartsWithS(&result->prettyName, "VanillaOS "))
     {
         ffStrbufSetStatic(&result->id, "vanilla");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
+        return true;
     }
 
+    if (ffPathExists("/usr/bin/lliurex-version", FF_PATHTYPE_FILE))
+    {
+        ffStrbufSetStatic(&result->name, "LliureX");
+        ffStrbufSetStatic(&result->id, "lliurex");
+        ffStrbufClear(&result->version);
+        if (ffProcessAppendStdOut(&result->version, (char* const[]) {
+            "/usr/bin/lliurex-version",
+            NULL,
+        }) == NULL) // 8.2.2
+            ffStrbufTrimRightSpace(&result->version);
+        ffStrbufSetF(&result->prettyName, "LliureX %s", result->version.chars);
+        ffStrbufSetStatic(&result->idLike, "ubuntu");
+        return true;
+    }
+
+    const char* xdgConfigDirs = getenv("XDG_CONFIG_DIRS");
+    if(!ffStrSet(xdgConfigDirs))
+        return false;
+
     if(ffStrContains(xdgConfigDirs, "kde") || ffStrContains(xdgConfigDirs, "plasma") || ffStrContains(xdgConfigDirs, "kubuntu"))
     {
         ffStrbufSetStatic(&result->name, "Kubuntu");
-        ffStrbufSetF(&result->prettyName, "Kubuntu %s", result->version.chars);
         ffStrbufSetStatic(&result->id, "kubuntu");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
-        return;
+        return false;
     }
 
     if(ffStrContains(xdgConfigDirs, "xfce") || ffStrContains(xdgConfigDirs, "xubuntu"))
     {
         ffStrbufSetStatic(&result->name, "Xubuntu");
-        ffStrbufSetF(&result->prettyName, "Xubuntu %s", result->version.chars);
         ffStrbufSetStatic(&result->id, "xubuntu");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
-        return;
+        return false;
     }
 
     if(ffStrContains(xdgConfigDirs, "lxqt") || ffStrContains(xdgConfigDirs, "lubuntu"))
     {
         ffStrbufSetStatic(&result->name, "Lubuntu");
-        ffStrbufSetF(&result->prettyName, "Lubuntu %s", result->version.chars);
         ffStrbufSetStatic(&result->id, "lubuntu");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
-        return;
+        return false;
     }
 
     if(ffStrContains(xdgConfigDirs, "budgie"))
     {
         ffStrbufSetStatic(&result->name, "Ubuntu Budgie");
-        ffStrbufSetF(&result->prettyName, "Ubuntu Budgie %s", result->version.chars);
         ffStrbufSetStatic(&result->id, "ubuntu-budgie");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
-        return;
+        return false;
     }
 
     if(ffStrContains(xdgConfigDirs, "cinnamon"))
     {
         ffStrbufSetStatic(&result->name, "Ubuntu Cinnamon");
-        ffStrbufSetF(&result->prettyName, "Ubuntu Cinnamon %s", result->version.chars);
         ffStrbufSetStatic(&result->id, "ubuntu-cinnamon");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
-        return;
+        return false;
     }
 
     if(ffStrContains(xdgConfigDirs, "mate"))
     {
         ffStrbufSetStatic(&result->name, "Ubuntu MATE");
-        ffStrbufSetF(&result->prettyName, "Ubuntu MATE %s", result->version.chars);
         ffStrbufSetStatic(&result->id, "ubuntu-mate");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
-        return;
+        return false;
     }
 
     if(ffStrContains(xdgConfigDirs, "studio"))
     {
         ffStrbufSetStatic(&result->name, "Ubuntu Studio");
-        ffStrbufSetF(&result->prettyName, "Ubuntu Studio %s", result->version.chars);
         ffStrbufSetStatic(&result->id, "ubuntu-studio");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
-        return;
+        return false;
     }
 
     if(ffStrContains(xdgConfigDirs, "sway"))
     {
         ffStrbufSetStatic(&result->name, "Ubuntu Sway");
-        ffStrbufSetF(&result->prettyName, "Ubuntu Sway %s", result->version.chars);
         ffStrbufSetStatic(&result->id, "ubuntu-sway");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
-        return;
+        return false;
     }
 
     if(ffStrContains(xdgConfigDirs, "touch"))
     {
         ffStrbufSetStatic(&result->name, "Ubuntu Touch");
-        ffStrbufSetF(&result->prettyName, "Ubuntu Touch %s", result->version.chars);
         ffStrbufSetStatic(&result->id, "ubuntu-touch");
         ffStrbufSetStatic(&result->idLike, "ubuntu");
-        return;
+        return false;
     }
 
-    if(ffStrContains(xdgConfigDirs, "lliurex"))
-    {
-        ffStrbufSetStatic(&result->name, "LliureX");
-        ffStrbufSetF(&result->prettyName, "LliureX %s", result->version.chars);
-        ffStrbufSetStatic(&result->id, "lliurex");
-        ffStrbufSetStatic(&result->idLike, "ubuntu");
-        return;
-    }
+    return false;
 }
 
 FF_MAYBE_UNUSED static void getDebianVersion(FFOSResult* result)
@@ -186,8 +187,10 @@ FF_MAYBE_UNUSED static void getDebianVersion(FFOSResult* result)
     ffAppendFileBuffer("/etc/debian_version", &debianVersion);
     ffStrbufTrimRightSpace(&debianVersion);
     if (!debianVersion.length) return;
-    ffStrbufSet(&result->version, &debianVersion);
-    ffStrbufSet(&result->versionID, &debianVersion);
+    ffStrbufDestroy(&result->versionID);
+    ffStrbufInitMove(&result->versionID, &debianVersion);
+
+    ffStrbufSetF(&result->prettyName, "%s %s (%s)", result->name.chars, result->versionID.chars, result->codename.chars);
 }
 
 FF_MAYBE_UNUSED static bool detectDebianDerived(FFOSResult* result)
@@ -306,16 +309,10 @@ FF_MAYBE_UNUSED static bool detectFedoraVariant(FFOSResult* result)
     return false;
 }
 
-static void detectOS(FFOSResult* os)
+static bool detectBedrock(FFOSResult* os)
 {
-    #ifdef FF_CUSTOM_OS_RELEASE_PATH
-    parseOsRelease(FF_STR(FF_CUSTOM_OS_RELEASE_PATH), os);
-        #ifdef FF_CUSTOM_LSB_RELEASE_PATH
-        parseLsbRelease(FF_STR(FF_CUSTOM_LSB_RELEASE_PATH), os);
-        #endif
-    return;
-    #endif
-
+    const char* bedrockRestrict = getenv("BEDROCK_RESTRICT");
+    if(bedrockRestrict && bedrockRestrict[0] == '1') return false;
     if(parseOsRelease(FASTFETCH_TARGET_DIR_ROOT "/bedrock" FASTFETCH_TARGET_DIR_ETC "/bedrock-release", os))
     {
         if(os->id.length == 0)
@@ -328,8 +325,23 @@ static void detectOS(FFOSResult* os)
             ffStrbufAppendS(&os->prettyName, "Bedrock Linux");
 
         parseOsRelease("/bedrock" FASTFETCH_TARGET_DIR_ETC "/os-release", os);
-        return;
+        return true;
     }
+    return false;
+}
+
+static void detectOS(FFOSResult* os)
+{
+    #ifdef FF_CUSTOM_OS_RELEASE_PATH
+    parseOsRelease(FF_STR(FF_CUSTOM_OS_RELEASE_PATH), os);
+        #ifdef FF_CUSTOM_LSB_RELEASE_PATH
+        parseLsbRelease(FF_STR(FF_CUSTOM_LSB_RELEASE_PATH), os);
+        #endif
+    return;
+    #endif
+
+    if (detectBedrock(os))
+        return;
 
     // Refer: https://gist.github.com/natefoo/814c5bf936922dad97ff
 
@@ -355,9 +367,15 @@ void ffDetectOSImpl(FFOSResult* os)
 {
     detectOS(os);
 
-    #ifdef __linux__
+    #if __linux__ || __GNU__
     if(ffStrbufEqualS(&os->id, "ubuntu"))
-        getUbuntuFlavour(os);
+    {
+        if (!getUbuntuFlavour(os))
+        {
+            if (!ffStrbufEndsWithS(&os->prettyName, " (development branch)"))
+                ffStrbufSetF(&os->prettyName, "%s %s", os->name.chars, os->version.chars); // os->version contains code name
+        }
+    }
     else if(ffStrbufEqualS(&os->id, "debian"))
     {
         if (!detectDebianDerived(os))
