@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_BATTERY_MODULE_NAME "Battery"
 
-void ffPrintBattery(FFBatteryOptions* options);
+bool ffPrintBattery(FFBatteryOptions* options);
 void ffInitBatteryOptions(FFBatteryOptions* options);
 void ffDestroyBatteryOptions(FFBatteryOptions* options);
+
+extern FFModuleBaseInfo ffBatteryModuleInfo;
