@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_BOARD_MODULE_NAME "Board"
 
-void ffPrintBoard(FFBoardOptions* options);
+bool ffPrintBoard(FFBoardOptions* options);
 void ffInitBoardOptions(FFBoardOptions* options);
 void ffDestroyBoardOptions(FFBoardOptions* options);
+
+extern FFModuleBaseInfo ffBoardModuleInfo;
