@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_DATETIME_MODULE_NAME "DateTime"
 
-void ffPrintDateTime(FFDateTimeOptions* options);
+bool ffPrintDateTime(FFDateTimeOptions* options);
 void ffInitDateTimeOptions(FFDateTimeOptions* options);
 void ffDestroyDateTimeOptions(FFDateTimeOptions* options);
+
+extern FFModuleBaseInfo ffDateTimeModuleInfo;
