@@ -4,8 +4,9 @@
 #include "modules/opengl/opengl.h"
 #include "util/stringUtils.h"
 
-void ffPrintOpenGL(FFOpenGLOptions* options)
+bool ffPrintOpenGL(FFOpenGLOptions* options)
 {
+    bool success = false;
     FFOpenGLResult result;
     ffStrbufInit(&result.version);
     ffStrbufInit(&result.renderer);
@@ -17,23 +18,25 @@ void ffPrintOpenGL(FFOpenGLOptions* options)
     if(error)
     {
         ffPrintError(FF_OPENGL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", error);
-        return;
-    }
-
-    if(options->moduleArgs.outputFormat.length == 0)
-    {
-        ffPrintLogoAndKey(FF_OPENGL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT);
-        puts(result.version.chars);
     }
     else
     {
-        FF_PRINT_FORMAT_CHECKED(FF_OPENGL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, ((FFformatarg[]) {
-            FF_FORMAT_ARG(result.version, "version"),
-            FF_FORMAT_ARG(result.renderer, "renderer"),
-            FF_FORMAT_ARG(result.vendor, "vendor"),
-            FF_FORMAT_ARG(result.slv, "slv"),
-            FF_FORMAT_ARG(result.library, "library"),
-        }));
+        if(options->moduleArgs.outputFormat.length == 0)
+        {
+            ffPrintLogoAndKey(FF_OPENGL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT);
+            puts(result.version.chars);
+        }
+        else
+        {
+            FF_PRINT_FORMAT_CHECKED(FF_OPENGL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, ((FFformatarg[]) {
+                FF_FORMAT_ARG(result.version, "version"),
+                FF_FORMAT_ARG(result.renderer, "renderer"),
+                FF_FORMAT_ARG(result.vendor, "vendor"),
+                FF_FORMAT_ARG(result.slv, "slv"),
+                FF_FORMAT_ARG(result.library, "library"),
+            }));
+        }
+        success = true;
     }
 
     ffStrbufDestroy(&result.version);
@@ -41,43 +44,20 @@ void ffPrintOpenGL(FFOpenGLOptions* options)
     ffStrbufDestroy(&result.vendor);
     ffStrbufDestroy(&result.slv);
     ffStrbufDestroy(&result.library);
-}
 
-bool ffParseOpenGLCommandOptions(FFOpenGLOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_OPENGL_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    if (ffStrEqualsIgnCase(subKey, "library"))
-    {
-        options->library = (FFOpenGLLibrary) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
-            { "auto", FF_OPENGL_LIBRARY_AUTO },
-            { "egl", FF_OPENGL_LIBRARY_EGL },
-            { "glx", FF_OPENGL_LIBRARY_GLX },
-            {}
-        });
-        return true;
-    }
-
-    return false;
+    return success;
 }
 
 void ffParseOpenGLJsonObject(FFOpenGLOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
-        if (ffStrEqualsIgnCase(key, "library"))
+        if (unsafe_yyjson_equals_str(key, "library"))
         {
             int value;
             const char* error = ffJsonConfigParseEnum(val, &value, (FFKeyValuePair[]) {
@@ -87,42 +67,37 @@ void ffParseOpenGLJsonObject(FFOpenGLOptions* options, yyjson_val* module)
                 {},
             });
             if (error)
-                ffPrintError(FF_OPENGL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Invalid %s value: %s", key, error);
+                ffPrintError(FF_OPENGL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Invalid %s value: %s", unsafe_yyjson_get_str(key), error);
             else
                 options->library = (FFOpenGLLibrary) value;
             continue;
         }
 
-        ffPrintError(FF_OPENGL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_OPENGL_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGenerateOpenGLJsonConfig(FFOpenGLOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyOpenGLOptions))) FFOpenGLOptions defaultOptions;
-    ffInitOpenGLOptions(&defaultOptions);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
-
-    if (options->library != defaultOptions.library)
+    switch (options->library)
     {
-        switch (options->library)
-        {
-        case FF_OPENGL_LIBRARY_AUTO:
-            yyjson_mut_obj_add_str(doc, module, "library", "auto");
-            break;
-        case FF_OPENGL_LIBRARY_EGL:
-            yyjson_mut_obj_add_str(doc, module, "library", "egl");
-            break;
-        case FF_OPENGL_LIBRARY_GLX:
-            yyjson_mut_obj_add_str(doc, module, "library", "glx");
-            break;
-        }
+    case FF_OPENGL_LIBRARY_AUTO:
+        yyjson_mut_obj_add_str(doc, module, "library", "auto");
+        break;
+    case FF_OPENGL_LIBRARY_EGL:
+        yyjson_mut_obj_add_str(doc, module, "library", "egl");
+        break;
+    case FF_OPENGL_LIBRARY_GLX:
+        yyjson_mut_obj_add_str(doc, module, "library", "glx");
+        break;
     }
 }
 
-void ffGenerateOpenGLJsonResult(FF_MAYBE_UNUSED FFOpenGLOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateOpenGLJsonResult(FF_MAYBE_UNUSED FFOpenGLOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
+    bool success = false;
     FFOpenGLResult result;
     ffStrbufInit(&result.version);
     ffStrbufInit(&result.renderer);
@@ -143,6 +118,7 @@ void ffGenerateOpenGLJsonResult(FF_MAYBE_UNUSED FFOpenGLOptions* options, yyjson
         yyjson_mut_obj_add_strbuf(doc, obj, "vendor", &result.vendor);
         yyjson_mut_obj_add_strbuf(doc, obj, "slv", &result.slv);
         yyjson_mut_obj_add_strbuf(doc, obj, "library", &result.library);
+        success = true;
     }
 
     ffStrbufDestroy(&result.version);
@@ -150,12 +126,27 @@ void ffGenerateOpenGLJsonResult(FF_MAYBE_UNUSED FFOpenGLOptions* options, yyjson
     ffStrbufDestroy(&result.vendor);
     ffStrbufDestroy(&result.slv);
     ffStrbufDestroy(&result.library);
+
+    return success;
 }
 
-static FFModuleBaseInfo ffModuleInfo = {
+void ffInitOpenGLOptions(FFOpenGLOptions* options)
+{
+    ffOptionInitModuleArg(&options->moduleArgs, "");
+
+    options->library = FF_OPENGL_LIBRARY_AUTO;
+}
+
+void ffDestroyOpenGLOptions(FFOpenGLOptions* options)
+{
+    ffOptionDestroyModuleArg(&options->moduleArgs);
+}
+
+FFModuleBaseInfo ffOpenGLModuleInfo = {
     .name = FF_OPENGL_MODULE_NAME,
     .description = "Print highest OpenGL version supported by the GPU",
-    .parseCommandOptions = (void*) ffParseOpenGLCommandOptions,
+    .initOptions = (void*) ffInitOpenGLOptions,
+    .destroyOptions = (void*) ffDestroyOpenGLOptions,
     .parseJsonObject = (void*) ffParseOpenGLJsonObject,
     .printModule = (void*) ffPrintOpenGL,
     .generateJsonResult = (void*) ffGenerateOpenGLJsonResult,
@@ -168,16 +159,3 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"OpenGL library used", "library"},
     }))
 };
-
-void ffInitOpenGLOptions(FFOpenGLOptions* options)
-{
-    options->moduleInfo = ffModuleInfo;
-    ffOptionInitModuleArg(&options->moduleArgs, "");
-
-    options->library = FF_OPENGL_LIBRARY_AUTO;
-}
-
-void ffDestroyOpenGLOptions(FFOpenGLOptions* options)
-{
-    ffOptionDestroyModuleArg(&options->moduleArgs);
-}
